@@ -1,10 +1,10 @@
-import os
 import pkg_resources
 import sys
 import time
 
 from collections import deque
 from json import dumps
+from pathlib import Path
 from pprint import pformat
 from signal import signal, SIGTERM, SIGUSR1, SIGTSTP, SIGCONT
 from subprocess import Popen
@@ -109,7 +109,7 @@ class CheckI3StatusThread(Task):
             self.notify_user(err)
         else:
             # check again in 5 seconds
-            self.timeout_queue_add(self, int(time.time()) + 5)
+            self.timeout_queue_add(self, int(time.perf_counter()) + 5)
 
 
 class ModuleRunner(Task):
@@ -182,14 +182,14 @@ class Common:
         NOTE: msg should not end in a '.' for consistency.
         """
         # Get list of paths that our stack trace should be found in.
-        py3_paths = [os.path.dirname(__file__)] + self.config["include_paths"]
+        py3_paths = [Path(__file__).resolve()] + self.config["include_paths"]
         traceback = None
 
         try:
             # We need to make sure to delete tb even if things go wrong.
             exc_type, exc_obj, tb = sys.exc_info()
             stack = extract_tb(tb)
-            error_str = "{}: {}\n".format(exc_type.__name__, exc_obj)
+            error_str = f"{exc_type.__name__}: {exc_obj}\n"
             traceback = [error_str]
 
             if error_frame:
@@ -197,7 +197,7 @@ class Common:
                 # should be made to appear correct.  We caught the exception
                 # but make it look as though we did not.
                 traceback += format_stack(error_frame, 1) + format_tb(tb)
-                filename = os.path.basename(error_frame.f_code.co_filename)
+                filename = Path(error_frame.f_code.co_filename).name
                 line_no = error_frame.f_lineno
             else:
                 # This is a none module based error
@@ -210,7 +210,7 @@ class Common:
                     for path in py3_paths:
                         if filename.startswith(path):
                             # Found a good trace
-                            filename = os.path.basename(item[0])
+                            filename = item[0].name
                             line_no = item[1]
                             found = True
                             break
@@ -222,7 +222,7 @@ class Common:
             )
         except:  # noqa e722
             # something went wrong report what we can.
-            msg = "{}.".format(msg)
+            msg = f"{msg}."
         finally:
             # delete tb!
             del tb
@@ -251,7 +251,7 @@ class Py3statusWrapper:
         """
         self.config = vars(options)
         self.i3bar_running = True
-        self.last_refresh_ts = time.time()
+        self.last_refresh_ts = time.perf_counter()
         self.lock = Event()
         self.modules = {}
         self.notified_messages = set()
@@ -344,7 +344,7 @@ class Py3statusWrapper:
         # process any items that need adding to the queue
         while self.timeout_add_queue:
             self.timeout_process_add_queue(*self.timeout_add_queue.popleft())
-        now = time.time()
+        now = time.perf_counter()
         due_timeouts = []
         # find any due timeouts
         for timeout in self.timeout_keys:
@@ -402,7 +402,7 @@ class Py3statusWrapper:
 
         # we return how long till we next need to process the timeout_queue
         if self.timeout_due is not None:
-            return self.timeout_due - time.time()
+            return self.timeout_due - time.perf_counter()
 
     def gevent_monkey_patch_report(self):
         """
@@ -444,17 +444,15 @@ class Py3statusWrapper:
         """
         user_modules = {}
         for include_path in self.config["include_paths"]:
-            for f_name in sorted(os.listdir(include_path)):
-                if not f_name.endswith(".py"):
+            for f_name in sorted(include_path.iterdir()):
+                if f_name.suffix != ".py":
                     continue
-                module_name = f_name[:-3]
+                module_name = f_name.stem
                 # do not overwrite modules if already found
                 if module_name in user_modules:
                     pass
                 user_modules[module_name] = (include_path, f_name)
-                self.log(
-                    "available module from {}: {}".format(include_path, module_name)
-                )
+                self.log(f"available module from {include_path}: {module_name}")
         return user_modules
 
     def _get_entry_point_based_modules(self):
@@ -463,15 +461,13 @@ class Py3statusWrapper:
             try:
                 module = entry_point.load()
             except Exception as err:
-                self.log("entry_point '{}' error: {}".format(entry_point, err))
+                self.log(f"entry_point '{entry_point}' error: {err}")
                 continue
             klass = getattr(module, Module.EXPECTED_CLASS, None)
             if klass:
                 module_name = entry_point.module_name.split(".")[-1]
                 classes_from_entry_points[module_name] = (ENTRY_POINT_KEY, klass)
-                self.log(
-                    "available module from {}: {}".format(ENTRY_POINT_KEY, module_name)
-                )
+                self.log(f"available module from {ENTRY_POINT_KEY}: {module_name}")
         return classes_from_entry_points
 
     def get_user_configured_modules(self):
@@ -519,10 +515,10 @@ class Py3statusWrapper:
                 if my_m.methods:
                     self.modules[module] = my_m
                 elif self.config["debug"]:
-                    self.log('ignoring module "{}" (no methods found)'.format(module))
+                    self.log(f'ignoring module "{module}" (no methods found)')
             except Exception:
                 err = sys.exc_info()[1]
-                msg = 'Loading module "{}" failed ({}).'.format(module, err)
+                msg = f'Loading module "{module}" failed ({err}).'
                 self.report_exception(msg, level="warning")
 
     def setup(self):
@@ -546,26 +542,26 @@ class Py3statusWrapper:
         try:
             # if running from git then log the branch and last commit
             # we do this by looking in the .git directory
-            git_path = os.path.join(os.path.dirname(__file__), "..", ".git")
+            git_path = Path(__file__).resolve().parent.parent / ".git"
             # branch
-            with open(os.path.join(git_path, "HEAD")) as f:
+            with (git_path / "HEAD").open() as f:
                 out = f.readline()
             branch = "/".join(out.strip().split("/")[2:])
-            self.log("git branch: {}".format(branch))
+            self.log(f"git branch: {branch}")
             # last commit
-            log_path = os.path.join(git_path, "logs", "refs", "heads", branch)
-            with open(log_path) as f:
+            log_path = git_path / "logs" / "refs" / "heads" / branch
+            with log_path.open() as f:
                 out = f.readlines()[-1]
             sha = out.split(" ")[1][:7]
             msg = ":".join(out.strip().split("\t")[-1].split(":")[1:])
-            self.log("git commit: {}{}".format(sha, msg))
+            self.log(f"git commit: {sha}{msg}")
         except:  # noqa e722
             pass
 
         self.log("window manager: {}".format(self.config["wm_name"]))
 
         if self.config["debug"]:
-            self.log("py3status started with config {}".format(self.config))
+            self.log(f"py3status started with config {self.config}")
 
         if self.config["gevent"]:
             self.is_gevent = self.gevent_monkey_patch_report()
@@ -597,7 +593,7 @@ class Py3statusWrapper:
             i3s_mode = "mocked"
         else:
             for module in i3s_modules:
-                self.log("adding module {}".format(module))
+                self.log(f"adding module {module}")
             i3s_mode = "started"
             self.i3status_thread.start()
             while not self.i3status_thread.ready:
@@ -641,8 +637,8 @@ class Py3statusWrapper:
 
         # suppress modules' output wrt issue #20
         if not self.config["debug"]:
-            sys.stdout = open("/dev/null", "w")
-            sys.stderr = open("/dev/null", "w")
+            sys.stdout = Path("/dev/null").open("w")
+            sys.stderr = Path("/dev/null").open("w")
 
         # get the list of py3status configured modules
         self.py3_modules = self.config["py3_config"]["py3_modules"]
@@ -651,7 +647,7 @@ class Py3statusWrapper:
         self.log("modules include paths: {}".format(self.config["include_paths"]))
         user_modules = self.get_user_configured_modules()
         if self.config["debug"]:
-            self.log("user_modules={}".format(user_modules))
+            self.log(f"user_modules={user_modules}")
 
         if self.py3_modules:
             # load and spawn i3status.conf configured modules threads
@@ -675,12 +671,12 @@ class Py3statusWrapper:
         dbus = self.config.get("dbus_notify")
         if dbus:
             # force msg, icon, title to be a string
-            title = "{}".format(title)
-            msg = "{}".format(msg)
+            title = f"{title}"
+            msg = f"{msg}"
             if icon:
-                icon = "{}".format(icon)
+                icon = f"{icon}"
         else:
-            msg = "py3status: {}".format(msg)
+            msg = f"py3status: {msg}"
         if level != "info" and module_name == "":
             fix_msg = "{} Please try to fix this and reload i3wm (Mod+Shift+R)"
             msg = fix_msg.format(msg)
@@ -693,17 +689,17 @@ class Py3statusWrapper:
         limit_key = ""
         if rate_limit:
             try:
-                limit_key = time.time() // rate_limit
+                limit_key = time.perf_counter() // rate_limit
             except TypeError:
                 pass
         # We use a hash to see if the message is being repeated.  This is crude
         # and imperfect but should work for our needs.
-        msg_hash = hash("{}#{}#{}#{}".format(module_name, limit_key, msg, title))
+        msg_hash = hash(f"{module_name}#{limit_key}#{msg}#{title}")
         if msg_hash in self.notified_messages:
             return
         elif module_name:
             log_msg = 'Module `{}` sent a notification. "{}: {}"'.format(
-                module_name, title, msg,
+                module_name, title, msg
             )
             self.log(log_msg, level)
         else:
@@ -728,9 +724,13 @@ class Py3statusWrapper:
                 cmd = [wm_nag, "-m", msg, "-t", level]
                 if nagbar_font:
                     cmd += ["-f", nagbar_font]
-            Popen(cmd, stdout=open("/dev/null", "w"), stderr=open("/dev/null", "w"))
+            Popen(
+                cmd,
+                stdout=Path("/dev/null").open("w"),
+                stderr=Path("/dev/null").open("w"),
+            )
         except Exception as err:
-            self.log("notify_user error: %s" % err)
+            self.log(f"notify_user error: {err}")
 
     def stop(self):
         """
@@ -764,8 +764,8 @@ class Py3statusWrapper:
         refreshes.
         """
         if not module_string:
-            if time.time() > (self.last_refresh_ts + 0.1):
-                self.last_refresh_ts = time.time()
+            if time.perf_counter() > (self.last_refresh_ts + 0.1):
+                self.last_refresh_ts = time.perf_counter()
             else:
                 # rate limiting
                 return
@@ -778,11 +778,11 @@ class Py3statusWrapper:
             ):
                 if module["type"] == "py3status":
                     if self.config["debug"]:
-                        self.log("refresh py3status module {}".format(name))
+                        self.log(f"refresh py3status module {name}")
                     module["module"].force_update()
                 else:
                     if self.config["debug"]:
-                        self.log("refresh i3status module {}".format(name))
+                        self.log(f"refresh i3status module {name}")
                     update_i3status = True
         if update_i3status:
             self.i3status_thread.refresh_i3status()
@@ -860,10 +860,10 @@ class Py3statusWrapper:
         if not self.config.get("log_file"):
             # If level was given as a str then convert to actual level
             level = LOG_LEVELS.get(level, level)
-            syslog(level, "{}".format(msg))
+            syslog(level, f"{msg}")
         else:
             # Binary mode so fs encoding setting is not an issue
-            with open(self.config["log_file"], "ab") as f:
+            with self.config["log_file"].open("ab") as f:
                 log_time = time.strftime("%Y-%m-%d %H:%M:%S")
                 # nice formatting of data structures using pretty print
                 if isinstance(msg, (dict, list, set, tuple)):
@@ -872,7 +872,7 @@ class Py3statusWrapper:
                     # to aid readability.
                     if "\n" in msg:
                         msg = "\n" + msg
-                out = "{} {} {}\n".format(log_time, level.upper(), msg)
+                out = f"{log_time} {level.upper()} {msg}\n"
                 try:
                     # Encode unicode strings to bytes
                     f.write(out.encode("utf-8"))
@@ -936,14 +936,18 @@ class Py3statusWrapper:
         Color processing occurs here.
         """
         outputs = module["module"].get_latest()
-        color = module["color"]
-        if color:
+        if self.config["py3_config"]["general"].get("colors") is False:
             for output in outputs:
-                # Color: substitute the config defined color
-                if "color" not in output:
-                    output["color"] = color
+                output.pop("color", None)
+        else:
+            color = module["color"]
+            if color:
+                for output in outputs:
+                    # Color: substitute the config defined color
+                    if "color" not in output:
+                        output["color"] = color
         # Create the json string output.
-        return ",".join([dumps(x) for x in outputs])
+        return ",".join(dumps(x) for x in outputs)
 
     def i3bar_stop(self, signum, frame):
         self.log("received SIGTSTP")
@@ -1038,7 +1042,7 @@ class Py3statusWrapper:
                         output[index] = out
 
                 # build output string
-                out = ",".join([x for x in output if x])
+                out = ",".join(x for x in output if x)
                 # dump the line to stdout
-                write(",[{}]\n".format(out))
+                write(f",[{out}]\n")
                 flush()
