@@ -106,6 +106,7 @@ SAMPLE OUTPUT
 
 from fnmatch import fnmatch
 from os import getloadavg
+from pathlib import Path
 
 import re
 
@@ -284,24 +285,24 @@ class Py3status:
                         break
 
     def _get_cpuinfo(self):
-        with open("/proc/cpuinfo") as f:
+        with Path("/proc/cpuinfo").open() as f:
             return [float(line.split()[-1]) for line in f if "cpu MHz" in line]
 
     def _calc_cpu_freqs(self, cpu_freqs, unit, keys):
         freq_avg, freq_max = None, None
         for key in keys:
             if key == "cpu_freq_avg":
-                value = sum(cpu_freqs) / len(cpu_freqs) * 1e6
+                value = sum(cpu_freqs) / len(cpu_freqs) * 10 ** 6
                 freq_avg, _ = self.py3.format_units(value, unit, si=True)
             elif key == "cpu_freq_max":
-                value = max(cpu_freqs) * 1e6
+                value = max(cpu_freqs) * 10 ** 6
                 freq_max, _ = self.py3.format_units(value, unit, si=True)
         return freq_avg, freq_max
 
     def _get_stat(self):
         # kernel/system statistics. man -P 'less +//proc/stat' procfs
         stat = []
-        with open("/proc/stat") as f:
+        with Path("/proc/stat").open() as f:
             for line in f:
                 if "cpu" in line:
                     stat.append(line)
@@ -312,7 +313,7 @@ class Py3status:
         # if avg, return (name, idle, total)
         if avg:
             fields = stat[0].split()
-            return "avg", int(fields[4]), sum(map(int, fields[1:]))
+            return "avg", int(fields[4]), sum(int(x) for x in fields[1:])
 
         # return a list of (name, idle, total)
         new_stat = []
@@ -327,7 +328,7 @@ class Py3status:
                 if cpu_name not in self.cpus["list"]:
                     continue
 
-            new_stat.append((cpu_name, int(fields[4]), sum(map(int, fields[1:]))))
+            new_stat.append((cpu_name, int(fields[4]), sum(int(x) for x in fields[1:])))
         return new_stat
 
     def _calc_mem_info(self, unit, meminfo, memory):
@@ -375,9 +376,9 @@ class Py3status:
             free_percent,
         )
 
-    def _get_meminfo(self, head=24):
-        with open("/proc/meminfo") as f:
-            info = [line.split() for line in (next(f) for x in range(head))]
+    def _get_meminfo(self, head=28):
+        with Path("/proc/meminfo").open() as f:
+            info = [next(f).split() for _ in range(head)]
             return {fields[0]: float(fields[1]) for fields in info}
 
     def _calc_cpu_percent(self, cpu):
@@ -422,7 +423,7 @@ class Py3status:
     def _get_cputemp(self, zone, unit):
         if zone is not None:
             try:
-                with open(zone) as f:
+                with Path(zone).open() as f:
                     cpu_temp = f.readline()
                     cpu_temp = float(cpu_temp) / 1000  # convert from mdegC to degC
             except (OSError, ValueError):
@@ -436,7 +437,7 @@ class Py3status:
 
         if cpu_temp is float:
             if unit == "°F":
-                cpu_temp = cpu_temp * (9.0 / 5.0) + 32
+                cpu_temp = cpu_temp * 9 / 5 + 32
             elif unit == "K":
                 cpu_temp += 273.15
 
