@@ -1,21 +1,16 @@
-from __future__ import division
-
 import os
 import sys
 import shlex
+import time
 
-try:
-    # Python 3.3+
-    from collections.abc import Mapping
-except ImportError:
-    from collections import Mapping
-
+from collections.abc import Mapping
 from copy import deepcopy
 from fnmatch import fnmatch
 from math import log10
+from pathlib import Path
 from pprint import pformat
+from shutil import which
 from subprocess import Popen, PIPE, STDOUT
-from time import time
 from uuid import uuid4
 
 from py3status import exceptions
@@ -26,18 +21,6 @@ from py3status.util import Gradients
 from py3status.version import version
 
 
-PY3_CACHE_FOREVER = -1
-PY3_LOG_ERROR = "error"
-PY3_LOG_INFO = "info"
-PY3_LOG_WARNING = "warning"
-
-# basestring does not exist in python3
-try:
-    basestring
-except NameError:
-    basestring = str
-
-
 class ModuleErrorException(Exception):
     """
     This exception is used to indicate that a module has returned an error
@@ -82,17 +65,17 @@ class Py3:
     being created.  All methods should work in this situation.
     """
 
-    CACHE_FOREVER = PY3_CACHE_FOREVER
+    CACHE_FOREVER = -1
     """
     Special constant that when returned for ``cached_until`` will cause the
     module to not update unless externally triggered.
     """
 
-    LOG_ERROR = PY3_LOG_ERROR
+    LOG_ERROR = "error"
     """Show as Error"""
-    LOG_INFO = PY3_LOG_INFO
+    LOG_INFO = "info"
     """Show as Informational"""
-    LOG_WARNING = PY3_LOG_WARNING
+    LOG_WARNING = "warning"
     """Show as Warning"""
 
     # Shared by all Py3 Instances
@@ -118,7 +101,6 @@ class Py3:
         self._format_color_names = {}
         self._format_placeholders = {}
         self._format_placeholders_cache = {}
-        self._is_python_2 = sys.version_info < (3, 0)
         self._module = module
         self._report_exception_cache = set()
         self._thresholds = None
@@ -144,7 +126,7 @@ class Py3:
         if it exists
         """
         if not name.startswith("COLOR_"):
-            raise AttributeError("Attribute `%s` not in Py3" % name)
+            raise AttributeError(f"Attribute `{name}` not in Py3")
         return self._get_config_setting(name.lower())
 
     def _get_config_setting(self, name, default=None):
@@ -315,7 +297,7 @@ class Py3:
             d = dict(enumerate(d))
         for k, v in d.items():
             if parent_key:
-                k = u"{}{}{}".format(parent_key, delimiter, k)
+                k = f"{parent_key}{delimiter}{k}"
             if intermediates:
                 items.append((k, v))
             if isinstance(v, list):
@@ -438,13 +420,6 @@ class Py3:
         """
         return self._i3s_config
 
-    def is_python_2(self):
-        """
-        True if the version of python being used is 2.x
-        Can be helpful for fixing python 2 compatibility issues
-        """
-        return self._is_python_2
-
     def is_gevent(self):
         """
         Checks if gevent monkey patching is enabled or not.
@@ -486,7 +461,7 @@ class Py3:
                 message = "\n" + message
         except:  # noqa e722
             pass
-        message = "Module `{}`: {}".format(self._module.module_full_name, message)
+        message = f"Module `{self._module.module_full_name}`: {message}"
         self._py3_wrapper.log(message, level)
 
     def update(self, module_name=None):
@@ -549,15 +524,9 @@ class Py3:
         if isinstance(msg, Composite):
             msg = msg.text()
         if title is None:
-            title = "py3status: {}".format(module_name)
+            title = f"py3status: {module_name}"
         elif isinstance(title, Composite):
             title = title.text()
-        # force unicode for python2 str
-        if self._is_python_2:
-            if isinstance(msg, str):
-                msg = msg.decode("utf-8")
-            if isinstance(title, str):
-                title = title.decode("utf-8")
         if msg:
             self._py3_wrapper.notify_user(
                 msg=msg,
@@ -656,7 +625,7 @@ class Py3:
                 if seconds:
                     seconds -= 0.1
 
-        requested = time() + seconds - offset
+        requested = time.perf_counter() + seconds - offset
 
         # if sync_to then we find the sync time for the requested time
         if sync_to:
@@ -742,7 +711,7 @@ class Py3:
 
         if not matches:
             return list(names)
-        elif isinstance(matches, basestring):
+        elif isinstance(matches, str):
             matches = [matches]
         # filter matches
         found = set()
@@ -779,7 +748,7 @@ class Py3:
 
         if not matches:
             return list(placeholders)
-        elif isinstance(matches, basestring):
+        elif isinstance(matches, str):
             matches = [matches]
         # filter matches
         found = set()
@@ -875,7 +844,7 @@ class Py3:
                 attr_getter=attr_getter,
             )
         except Exception:
-            self._report_exception(u"Invalid format `{}`".format(format_string))
+            self._report_exception(f"Invalid format `{format_string}`")
             return "invalid format"
 
     def build_composite(
@@ -911,7 +880,7 @@ class Py3:
                 attr_getter=attr_getter,
             )
         except Exception:
-            self._report_exception(u"Invalid format `{}`".format(format_string))
+            self._report_exception(f"Invalid format `{format_string}`")
             return [{"full_text": "invalid format"}]
 
     def composite_update(self, item, update_dict, soft=False):
@@ -958,7 +927,7 @@ class Py3:
 
     def check_commands(self, cmd_list):
         """
-        Checks to see if commands in list are available using ``which``.
+        Checks to see if commands in list are available using shutil.which().
 
         returns the first available command.
 
@@ -966,11 +935,11 @@ class Py3:
         """
         # if a string is passed then convert it to a list.  This prevents an
         # easy mistake that could be made
-        if isinstance(cmd_list, basestring):
+        if isinstance(cmd_list, str):
             cmd_list = [cmd_list]
 
         for cmd in cmd_list:
-            if self.command_run("which {}".format(cmd)) == 0:
+            if which(cmd) is not None:
                 return cmd
 
     def command_run(self, command):
@@ -981,17 +950,17 @@ class Py3:
         An Exception is raised if an error occurs
         """
         # convert the command to sequence if a string
-        if isinstance(command, basestring):
+        if isinstance(command, str):
             command = shlex.split(command)
         try:
             return Popen(command, stdout=PIPE, stderr=PIPE, close_fds=True).wait()
         except Exception as e:
             # make a pretty command for error loggings and...
-            if isinstance(command, basestring):
+            if isinstance(command, str):
                 pretty_cmd = command
             else:
                 pretty_cmd = " ".join(command)
-            msg = "Command `{cmd}` {error}".format(cmd=pretty_cmd, error=e.errno)
+            msg = f"Command `{pretty_cmd}` {e.errno}"
             raise exceptions.CommandError(msg, error_code=e.errno)
 
     def command_output(
@@ -1009,12 +978,12 @@ class Py3:
         A CommandError is raised if an error occurs
         """
         # make a pretty command for error loggings and...
-        if isinstance(command, basestring):
+        if isinstance(command, str):
             pretty_cmd = command
         else:
             pretty_cmd = " ".join(command)
         # convert the non-shell command to sequence if it is a string
-        if not shell and isinstance(command, basestring):
+        if not shell and isinstance(command, str):
             command = shlex.split(command)
 
         stderr = STDOUT if capture_stderr else PIPE
@@ -1031,14 +1000,11 @@ class Py3:
                 env=env,
             )
         except Exception as e:
-            msg = "Command `{cmd}` {error}".format(cmd=pretty_cmd, error=e)
+            msg = f"Command `{pretty_cmd}` {e}"
             self.log(msg)
             raise exceptions.CommandError(msg, error_code=e.errno)
 
         output, error = process.communicate()
-        if self._is_python_2 and isinstance(output, str):
-            output = output.decode("utf-8")
-            error = error.decode("utf-8")
         retcode = process.poll()
         if retcode:
             # under certain conditions a successfully run command may get a
@@ -1064,7 +1030,7 @@ class Py3:
         Ensure that storage is initialized.
         """
         if not self._storage.initialized:
-            self._storage.init(self._module._py3_wrapper, self._is_python_2)
+            self._storage.init(self._module._py3_wrapper)
 
     def storage_set(self, key, value):
         """
@@ -1139,8 +1105,8 @@ class Py3:
             if cmd:
                 if cmd == "ffplay":
                     cmd = "ffplay -autoexit -nodisp -loglevel 0"
-                sound_file = os.path.expanduser(sound_file)
-                c = shlex.split("{} {}".format(cmd, sound_file))
+                sound_file = Path(sound_file).expanduser()
+                c = shlex.split(f"{cmd} {sound_file}")
                 self._audio = Popen(c)
 
     def stop_sound(self):
@@ -1198,7 +1164,7 @@ class Py3:
         # skip on empty thresholds/values
         if not thresholds or value in [None, ""]:
             pass
-        elif isinstance(value, basestring):
+        elif isinstance(value, str):
             # string
             for threshold in thresholds:
                 if value == threshold[0]:
@@ -1244,7 +1210,7 @@ class Py3:
 
         # save color so it can be accessed via safe_format()
         if name:
-            color_name = "color_threshold_%s" % name
+            color_name = f"color_threshold_{name}"
         else:
             color_name = "color_threshold"
         setattr(self._py3status_module, color_name, color)
@@ -1306,7 +1272,7 @@ class Py3:
             retry_wait = getattr(self._py3status_module, "request_retry_wait", 2)
 
         if "User-Agent" not in headers:
-            headers["User-Agent"] = "py3status/{} {}".format(version, self._uid)
+            headers["User-Agent"] = f"py3status/{version} {self._uid}"
 
         def get_http_response():
             return HttpResponse(
@@ -1327,8 +1293,8 @@ class Py3:
                     from gevent import sleep
                 else:
                     from time import sleep
-                self.log("HTTP request retry {}/{}".format(n, retry_times))
+                self.log(f"HTTP request retry {n}/{retry_times}")
                 sleep(retry_wait)
-        self.log("HTTP request retry {}/{}".format(retry_times, retry_times))
+        self.log(f"HTTP request retry {retry_times}/{retry_times}")
         sleep(retry_wait)
         return get_http_response()
